
class handler():
    def __init__(self):
        self.red = "\033[1;31m"
        self.white = "\033[1;37m"
        self.normal = "\033[0;0m"
        self.blue = "\033[1;34m"

    def exception(self, exception):
        print(f"{self.red}[{self.white}Error{self.red}]{self.white} {str(exception)} {self.normal}")

    def info(self, message):
        print(f"{self.blue}[{self.white}INFO{self.blue}]{self.white} {str(message)} {self.normal}")


import requests
from ..utils.url import joinURL
from ..utils.alerts import handler
from typing import Optional

class NasaAPI:
    """Clase principal para interactuar con la API de NASA."""
    
    def __init__(self, api_key:str):
        """
        Inicializa la clase con la clave de API y la URL base.
        
        :param api_key: Clave de API para autenticar las solicitudes.
        """
        self.api_key = api_key
        self.base_url = "https://api.nasa.gov/"

    def _get_url(self, endpoint, params=None):
        """
        Construye la URL completa para una solicitud.
        
        :param endpoint: El endpoint de la API.
        :param params: Parámetros adicionales para la solicitud.
        :return: La URL completa.
        """
        url = joinURL(self.base_url, endpoint)
        if params:
            url += f"?{params}"
        return url

    def get_apod(self, date: Optional[str] = None, 
                 start_date: Optional[str] = None, 
                 end_date: Optional[str] = None,
                 count: Optional[int] = None, 
                 thumbs: bool = False) -> Optional[dict]:
        """
        Obtiene la Imagen del Día de la NASA (APOD) para una fecha específica, un rango de fechas o imágenes aleatorias.

        Args:
            date (Optional[str]): Fecha específica para la APOD en formato 'YYYY-MM-DD'. Si no se proporciona, se obtiene la imagen del día actual.
            start_date (Optional[str]): Fecha de inicio en formato 'YYYY-MM-DD' para un rango de fechas.
            end_date (Optional[str]): Fecha de fin en formato 'YYYY-MM-DD' para un rango de fechas. Si no se proporciona, se usa la fecha actual.
            count (Optional[int]): Número de imágenes aleatorias a devolver. No se puede usar con `date` o `start_date` y `end_date`.
            thumbs (bool): Si es True, devuelve la URL de la miniatura del video. Si no es un video, este parámetro se ignora.

        Returns:
            Optional[dict]: La respuesta JSON de la API, o None si la solicitud falla o no hay datos disponibles.
        """
        endpoint = "planetary/apod"
        params = f"api_key={self.api_key}"
        
        if date:
            params += f"&date={date}"
        if start_date:
            params += f"&start_date={start_date}"
        if end_date:
            params += f"&end_date={end_date}"
        if count:
            params += f"&count={count}"
        if thumbs:
            params += f"&thumbs=True"
        
        url = self._get_url(endpoint, params)
        
        try:
            response = requests.get(url)
            response.raise_for_status()  # Lanza una excepción para códigos de estado HTTP no exitosos
        except requests.RequestException as e:
            handler(f"Error al obtener APOD: {e}")  # Usa el manejador de alertas si ocurre un error
            return None
        
        return response.json()

# Ejemplo de uso
if __name__ == "__main__":
    api = NasaAPI(api_key="DEMO_KEY")
    apod_data = api.get_apod()
    if apod_data:
        print(f"Title: {apod_data.get('title')}")
        print(f"Explanation: {apod_data.get('explanation')}")
        print(f"URL: {apod_data.get('url')}")




from typing import Optional, Union

from ..utils.alerts import handler
from ..core.api import NasaAPI

from ..api.apod import get_apod
from ..api.apod import Apod

class NASA:
    def __init__(self, api_key: str="DEMO_KEY"):
        """
        Inicializa la instancia de NASA con la clave API.

        Args:
            api_key (str): Clave API para acceder a los datos de la NASA.
        """
        self.api_key = api_key
        handler().info("Se está usando la DEMO_KEY, puedes conseguir la tuya en https://api.nasa.gov/") if api_key == "DEMO_KEY" else "" 
        self.API = NasaAPI(api_key)

    def apod(self, date: Optional[str] = None, 
             start_date: Optional[str] = None, 
             end_date: Optional[str] = None,
             count: Optional[int] = None, 
             thumbs: bool = False) -> Union[Apod, list[Apod]]:
        """
        Obtiene la Imagen del Día de la NASA (APOD) para una fecha específica, un rango de fechas o imágenes aleatorias.

        Args:
            date (Optional[str]): La fecha para la APOD en formato 'YYYY-MM-DD'. Si es None, se obtiene la APOD de hoy.
            start_date (Optional[str]): Fecha de inicio en formato 'YYYY-MM-DD' para un rango de fechas. No se puede usar con `date`.
            end_date (Optional[str]): Fecha de fin en formato 'YYYY-MM-DD' para un rango de fechas. Si es None, se usa la fecha actual.
            count (Optional[int]): Número de imágenes aleatorias a devolver. No se puede usar con `date` o `start_date` y `end_date`.
            thumbs (bool): Si es True, devuelve la URL de la miniatura del video. Si no es un video, este parámetro se ignora.

        Returns:
            Union[Apod, list[Apod], None]: Una instancia de la clase Apod con los detalles de la Imagen del Día de la NASA,
                                o una lista llena de Apods,
                                o None si la solicitud falla o no hay datos disponibles.
        """
        # Llamar a la función get_apod con todos los parámetros proporcionados
        apod_data = get_apod(
                            API=self.API,
                            date=date, 
                            start_date=start_date, 
                            end_date=end_date, 
                            count=count, 
                            thumbs=thumbs
                            )
        
        # Verificar si se obtuvo una respuesta válida
        if apod_data is None:
            return None

        return apod_data



import pynasa, datetime

def test_apod():
    nasa = pynasa.NASA(key="DEMO_KEY")
    apod = nasa.apod()
    assert apod != None
    assert apod.title != None
    assert apod.date == datetime.datetime.today().strftime('%Y-%m-%d')




from setuptools import setup, find_packages

with open('README.rst', 'r') as f:
    README = f.read()

setup(
    name='pynasa',
    version='1.0.0',
    description='Python library and command-line utility for the NASA API (https://api.nasa.gov/)',
    long_description=README,
    long_description_content_type='text/x-rst',
    author='Giovanny Jimenez',
    author_email='gjimenezdeza@gmail.com',
    url='https://github.com/techatlasdev/pynasa',
    packages=find_packages(),
    install_requires=[
        'requests',
    ],
    entry_points={
        'console_scripts': [
            'pynasa=pynasa.cli.commands:main',
        ],
    },
    keywords=['NASA', 'API', 'space', 'astronomy', 'science', 'data', 'python'],
    classifiers=[
        'Development Status :: 5 - Production/Stable',
        'Intended Audience :: Developers',
        'License :: OSI Approved :: MIT License',
        'Natural Language :: English',
        'Operating System :: OS Independent',
        'Programming Language :: Python',
        'Programming Language :: Python :: 3',
        'Programming Language :: Python :: 3.6',
        'Programming Language :: Python :: 3.7',
        'Programming Language :: Python :: 3.8',
        'Programming Language :: Python :: 3.9',
        'Programming Language :: Python :: 3.10',
        'Programming Language :: Python :: 3.11',
        'Topic :: Software Development :: Libraries :: Python Modules',
        'Topic :: Scientific/Engineering :: Astronomy',
    ],
)



import argparse
from ..core import NasaAPI
from ..utils import format_response

def get_apod(api_key, date):
    api = NasaAPI(api_key=api_key)
    response = api.get_apod(date=date)
    formatted_response = format_response(response)
    print(formatted_response)

def main():
    parser = argparse.ArgumentParser(description='Pynasa CLI - Interact with the NASA API')
    parser.add_argument('api_key', help='Your NASA API key')
    parser.add_argument('date', help='Date for APOD (yyyy-mm-dd)')
    args = parser.parse_args()
    
    get_apod(api_key=args.api_key, date=args.date)

if __name__ == "__main__":
    main()